@@ -33,6 +33,7 @@ import websocket
 
 import docker
 
+from zunclient.common.apiclient import exceptions as acexceptions
 from zunclient.common.websocketclient import exceptions
 
 LOG = logging.getLogger(__name__)
@@ -144,7 +145,6 @@ class BaseClient(object):
             self.quit = True
 
         data = os.read(sys.stdin.fileno(), 1024)
-        LOG.debug('read %s (%d bytes) from stdin', repr(data), len(data))
 
         if not data:
             return
@@ -173,8 +173,6 @@ class BaseClient(object):
             self.quit = True
 
         data = self.recv()
-        LOG.debug('read %s (%d bytes) from socket from container',
-                  repr(data), len(data))
         if not data:
             self.poll.unregister(self.fileno())
             self.quit = True
@@ -198,6 +196,8 @@ class BaseClient(object):
                 self.tty_resize(height=rows, width=cols)
             except IOError:  # Container already exited
                 pass
+            except acexceptions.BadRequest:
+                pass
 
     def tty_size(self, fd):
         """Get the tty size
