@@ -53,17 +53,20 @@ except ImportError:
     pass
 
 from zunclient import api_versions
+from zunclient import client as base_client
 from zunclient.common.apiclient import auth
 from zunclient.common import cliutils
 from zunclient import exceptions as exc
+from zunclient.experimental import client as client_experimental
+from zunclient.experimental import shell as shell_experimental
 from zunclient.i18n import _
-from zunclient.v1 import client as client_v1
 from zunclient.v1 import shell as shell_v1
 from zunclient import version
 
-DEFAULT_API_VERSION = '1.2'
+DEFAULT_API_VERSION = api_versions.DEFAULT_API_VERSION
 DEFAULT_ENDPOINT_TYPE = 'publicURL'
 DEFAULT_SERVICE_TYPE = 'container'
+EXPERIENTAL_SERVICE_TYPE = 'container-experimental'
 
 logger = logging.getLogger(__name__)
 
@@ -136,7 +139,7 @@ class SecretsHelper(object):
         if not HAS_KEYRING or not self.args.os_cache:
             return
         if (auth_token == self.auth_token and
-           management_url == self.management_url):
+                management_url == self.management_url):
             # Nothing changed....
             return
         if not all([management_url, auth_token, tenant_id]):
@@ -361,6 +364,10 @@ class OpenStackZunShell(object):
                             action='store_true',
                             help="Do not verify https connections")
 
+        parser.add_argument('--experimental-api',
+                            action='store_true',
+                            help="Using experimental API")
+
         if profiler:
             parser.add_argument('--profile',
                                 metavar='HMAC_KEY',
@@ -382,21 +389,22 @@ class OpenStackZunShell(object):
 
         return parser
 
-    def get_subcommand_parser(self, version, do_help=False):
+    def get_subcommand_parser(self, version, experimental, do_help=False):
         parser = self.get_base_parser()
 
         self.subcommands = {}
         subparsers = parser.add_subparsers(metavar='<subcommand>')
 
         try:
-            actions_modules = {
-                '1': shell_v1.COMMAND_MODULES
-            }[version.ver_major]
+            actions_modules = shell_v1.COMMAND_MODULES
+            if experimental:
+                for items in shell_experimental.COMMAND_MODULES:
+                    actions_modules.append(items)
         except KeyError:
             actions_modules = shell_v1.COMMAND_MODULES
 
-        for actions_module in actions_modules:
-            self._find_actions(subparsers, actions_module, version, do_help)
+        for action_modules in actions_modules:
+            self._find_actions(subparsers, action_modules, version, do_help)
         self._find_actions(subparsers, self, version, do_help)
 
         self._add_bash_completion_subparser(subparsers)
@@ -504,8 +512,12 @@ class OpenStackZunShell(object):
             spot = argv.index('--endpoint_type')
             argv[spot] = '--endpoint-type'
 
+        experimental = False
+        if '--experimental-api' in argv:
+            experimental = True
+
         subcommand_parser = self.get_subcommand_parser(
-            api_version, do_help=("help" in args))
+            api_version, experimental, do_help=("help" in args))
 
         self.parser = subcommand_parser
 
@@ -549,6 +561,9 @@ class OpenStackZunShell(object):
 
         if not service_type:
             service_type = DEFAULT_SERVICE_TYPE
+
+        if experimental:
+            service_type = EXPERIENTAL_SERVICE_TYPE
 # NA - there is only one service this CLI accesses
 #            service_type = utils.get_service_type(args.func) or service_type
 
@@ -575,16 +590,16 @@ class OpenStackZunShell(object):
                     os_auth_url = auth_plugin.get_auth_url()
 
             if not os_auth_url:
-                    raise exc.CommandError("You must provide an auth url "
-                                           "via either --os-auth-url or "
-                                           "env[OS_AUTH_URL] or specify an "
-                                           "auth_system which defines a "
-                                           "default url with --os-auth-system "
-                                           "or env[OS_AUTH_SYSTEM]")
+                raise exc.CommandError("You must provide an auth url "
+                                       "via either --os-auth-url or "
+                                       "env[OS_AUTH_URL] or specify an "
+                                       "auth_system which defines a "
+                                       "default url with --os-auth-system "
+                                       "or env[OS_AUTH_SYSTEM]")
 
-# NOTE: The Zun client authenticates when you create it. So instead of
-#       creating here and authenticating later, which is what the novaclient
-#       does, we just create the client later.
+        # NOTE: The Zun client authenticates when you create it. So instead of
+        #       creating here and authenticating later, which is what the
+        #       novaclient does, we just create the client later.
 
         # Now check for the password/token of which pieces of the
         # identifying keyring key can come from the underlying client
@@ -608,19 +623,18 @@ class OpenStackZunShell(object):
                         '--os-password, env[OS_PASSWORD], or '
                         'prompted response')
 
-        try:
-            client = {
-                '1': client_v1,
-            }[api_version.ver_major]
-        except KeyError:
-            client = client_v1
+        if experimental:
+            client = client_experimental
+        else:
+            client = base_client
 
         kwargs = {}
         if profiler:
             kwargs["profile"] = args.profile
 
-        self.cs = client.Client(username=os_username,
-                                api_key=os_password,
+        self.cs = client.Client(version=api_version,
+                                username=os_username,
+                                password=os_password,
                                 project_id=os_project_id,
                                 project_name=os_project_name,
                                 user_domain_id=os_user_domain_id,
@@ -630,10 +644,9 @@ class OpenStackZunShell(object):
                                 auth_url=os_auth_url,
                                 service_type=service_type,
                                 region_name=args.os_region_name,
-                                zun_url=bypass_url,
-                                endpoint_type=endpoint_type,
+                                endpoint_override=bypass_url,
+                                interface=endpoint_type,
                                 insecure=insecure,
-                                api_version=api_version,
                                 **kwargs)
 
         args.func(self.cs, args)
@@ -678,7 +691,6 @@ class OpenStackZunShell(object):
         """Display help about this program or one of its subcommands."""
         # NOTE(jamespage): args.command is not guaranteed with python >= 3.4
         command = getattr(args, 'command', '')
-
         if command:
             if args.command in self.subcommands:
                 self.subcommands[args.command].print_help()
